package tezos-bls12-381-polynomial

  1. Overview
  2. Docs

Source file bls12_381_polynomial.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
(*****************************************************************************)
(*                                                                           *)
(* MIT License                                                               *)
(* Copyright (c) 2022 Nomadic Labs <contact@nomadic-labs.com>                *)
(*                                                                           *)
(* Permission is hereby granted, free of charge, to any person obtaining a   *)
(* copy of this software and associated documentation files (the "Software"),*)
(* to deal in the Software without restriction, including without limitation *)
(* the rights to use, copy, modify, merge, publish, distribute, sublicense,  *)
(* and/or sell copies of the Software, and to permit persons to whom the     *)
(* Software is furnished to do so, subject to the following conditions:      *)
(*                                                                           *)
(* The above copyright notice and this permission notice shall be included   *)
(* in all copies or substantial portions of the Software.                    *)
(*                                                                           *)
(* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR*)
(* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  *)
(* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL   *)
(* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER*)
(* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING   *)
(* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER       *)
(* DEALINGS IN THE SOFTWARE.                                                 *)
(*                                                                           *)
(*****************************************************************************)

module type S = sig
  type scalar

  module Domain : Domain.Domain_sig with type scalar = scalar
  module Polynomial : Polynomial.Polynomial_sig with type scalar = scalar

  module Evaluations :
    Evaluations.Evaluations_sig
      with type scalar = scalar
       and type domain = Domain.t
       and type polynomial = Polynomial.t

  module Srs : sig
    module Srs_g1 : Srs.S with type polynomial = Polynomial.t
    module Srs_g2 : Srs.S with type polynomial = Polynomial.t

    type t = Srs_g1.t * Srs_g2.t

    val generate_insecure : int -> int -> t
    val check : t -> unit
  end
end

type scalar = Bls12_381.Fr.t

module Domain = Domain
module Polynomial = Polynomial
module Evaluations = Evaluations
module Srs = Srs.Srs